package v2

import (
	"context"
	"fmt"

	"quark.netapp.io/volume-controller/pkg/quarkconfig"

	apierrors "k8s.io/apimachinery/pkg/api/errors"
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"

	log "github.com/sirupsen/logrus"
)

// ServiceMeshAnthosCleanup deletes ASM control plane resources. This API should only
// be called after the fleet mesh for the cluster has been updated to 'manual' mode. Otherwise,
// these resources will be re-created by google managed controllers.
func (client *NVCClient) ServiceMeshAnthosCleanup(ctx context.Context) error {
	var err error
	validatingWebhookName := "istiod-istio-system-mcp"
	err = client.GetKubeClient().AdmissionregistrationV1().
		ValidatingWebhookConfigurations().
		Delete(ctx, validatingWebhookName, metav1.DeleteOptions{})
	if err != nil && !apierrors.IsNotFound(err) {
		return fmt.Errorf("error deleting validating webhook '%v': %v", validatingWebhookName, err)
	}
	log.Debugf("Successfully deleted validatingwebhookconfiguration '%v'", validatingWebhookName)

	err = client.GetKubeClient().AdmissionregistrationV1().
		MutatingWebhookConfigurations().
		DeleteCollection(ctx, metav1.DeleteOptions{}, metav1.ListOptions{
			LabelSelector: quarkconfig.RevisionLabel,
		})
	if err != nil {
		return fmt.Errorf("error deleting all service mesh mutating webhooks with selector '%v': %v",
			quarkconfig.RevisionLabel, err)
	}
	log.Debugf("Successfully deleted all mutatingwebhookconfigurations with label '%v'", quarkconfig.RevisionLabel)

	deleteNamespace := func(namespace string) error {
		err := client.GetKubeClient().CoreV1().
			Namespaces().
			Delete(ctx, namespace, metav1.DeleteOptions{})
		if err != nil && !apierrors.IsNotFound(err) {
			return fmt.Errorf("error deleting '%v' namespace: %v", namespace, err)
		}
		log.Debugf("Successfully deleted namespace '%v'", namespace)
		return nil
	}
	if err := deleteNamespace(quarkconfig.IstioSystemNamespace); err != nil {
		return err
	}
	if err := deleteNamespace(quarkconfig.ASMSystemNamespace); err != nil {
		return err
	}
	return nil
}
